import PropTypes from 'prop-types';
import { Container, Navbar, Nav } from 'react-bootstrap';
import { Link, useLocation, useNavigate } from 'react-router-dom';
import { useContext } from 'react';
import { CurrentUserContext } from '../../contexts/CurrentUserContext';
import { Person } from 'react-bootstrap-icons';

const Header = ({ routes }) => {
    const location = useLocation();
    const navigate = useNavigate();
    const { currentUser, setCurrentUser } = useContext(CurrentUserContext);
    const indexPageLink = routes.filter((route) => route.index === false).shift();
    const currentPage = routes.filter((route) => route.path === location.pathname)[0];
    if (currentUser) {
        routes = routes.filter((route) => !route.onlyNoAuthorized && route.onlyTeachers == null || route.onlyTeachers == currentUser.isTeacher);
    }
    else {
        routes = routes.filter((route) => !route.onlyAuthorized);
    }

    return (
        <header className='sticky-top bg-dark mb-2'>
            <Navbar expand='md'>
                <Container fluid>
                    <Navbar.Brand as={Link} to={indexPageLink?.path ?? '/'}>
                        Учебный процесс
                    </Navbar.Brand>
                    <Navbar.Toggle aria-controls='main-navbar' />
                    <Navbar.Collapse id='main-navbar'>
                        <Nav className='me-auto link' activeKey={location.pathname}>
                            {
                                routes.map((route, index) =>
                                    <Nav.Link as={Link} key={index} to={route.path ?? '/'} active={route == currentPage}>
                                        {route.title}
                                    </Nav.Link>
                                )
                            }
                            {
                                currentUser != null ? <div className='badge d-flex align-items-center d-md-none'><Person fill='white' className='me-1' /><span>{currentUser.name} {currentUser.surname}</span><button className='ms-3 btn btn-outline-danger btn-sm' onClick={() => { setCurrentUser(null); navigate('/'); }}>Выход</button></div> : ""
                            }
                        </Nav>
                    </Navbar.Collapse>
                    {
                        currentUser ? <div className='badge d-none d-md-flex align-items-center me-3'><Person fill='white' className='me-1' /><span>{currentUser.name} {currentUser.surname}</span></div> : ""
                    }
                    {
                        currentUser ? <button className='btn btn-outline-danger btn-sm d-none d-md-block' onClick={() => { setCurrentUser(null); navigate('/'); }}>Выход</button> : ''
                    }
                </Container>
            </Navbar >
        </header>
    );
};

Header.propTypes = {
    routes: PropTypes.array,
};

export default Header;
