import { useEffect, useState } from "react";
import UsersApiService from "../services/UsersApiService";
import { useNavigate } from "react-router-dom";
import { useContext } from "react";
import { CurrentUserContext } from "../contexts/CurrentUserContext";

export const useOnlyAuthorized = () => {
    const navigate = useNavigate();
    const { currentUser } = useContext(CurrentUserContext);
    useEffect(() => {
        if (!currentUser) {
            navigate("/auth");
        }
    });
};

export const useOnlyTeachers = () => {
    const navigate = useNavigate();
    const { currentUser } = useContext(CurrentUserContext);
    useEffect(() => {
        if (!currentUser || !currentUser.isTeacher) {
            navigate("/auth");
        }
    });
};

export const useUserByUsername = (username) => {
    const [usersRefresh, setUsersRefresh] = useState(false);
    const [user, setUser] = useState(null);
    const handleUsersRefresh = () => setUsersRefresh(!usersRefresh);

    const getUser = async () => {
        if (!username) {
            setUser(null);
            return;
        }
        const expand = `?username=${username}`;
        const data = await UsersApiService.getAll(expand);
        setUser(data.pop() ?? null);
    };

    useEffect(() => {
        getUser();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [usersRefresh, username]);

    return {
        user,
        handleUsersRefresh,
    };
};

export const useUsers = () => {
    const [usersRefresh, setUsersRefresh] = useState(false);
    const [users, setUsers] = useState([]);
    const handleUsersRefresh = () => setUsersRefresh(!usersRefresh);

    const getUsers = async () => {
        const data = await UsersApiService.getAll();
        setUsers(data ?? []);
    };

    useEffect(() => {
        getUsers();
    });

    return {
        users,
        handleUsersRefresh,
    };
};

export const useStudents = (filters = null) => {
    const [studentsRefresh, setStudentsRefresh] = useState(false);
    const [students, setStudents] = useState([]);
    const handleStudentsChange = () => setStudentsRefresh(!studentsRefresh);

    const getStudents = async () => {
        let expand = `?isTeacher=false&_expand=group&_sort=surname,name`;
        if (filters && Object.keys(filters).length !== 0) {
            for (let index = 0; index < Object.keys(filters).length; index++) {
                const key = Object.keys(filters)[index];
                const v = filters[key];
                if (v) {
                    expand += `&${key}=${v}`;
                }
            }
        }
        const data = await UsersApiService.getAll(expand);
        setStudents(data ?? []);
    };

    useEffect(() => {
        getStudents();
        // eslint-disable-next-line react-hooks/exhaustive-deps
    }, [studentsRefresh]);

    return {
        students,
        handleStudentsChange,
    };
};
