import 'bootstrap/dist/css/bootstrap.min.css'
import { RouterProvider, createBrowserRouter } from 'react-router-dom'
import React from 'react'
import ReactDOM from 'react-dom/client'
import App from './App.jsx'
import { Toaster } from 'react-hot-toast'
import './index.css'
import ErrorPage from './pages/ErrorPage/ErrorPage.jsx'
import MainPage from './pages/MainPage/MainPage.jsx'
import AuthPage from './pages/AuthPage/AuthPage.jsx'
import RegisterPage from './pages/RegisterPage/RegisterPage.jsx'
import StatementsPage from './pages/StatementsPage/StatementsPage.jsx'
import SubjectsPage from './pages/SubjectsPage/SubjectsPage.jsx'
import GroupsPage from './pages/GroupsPage/GroupsPage.jsx'
import StudentsPage from './pages/StudentsPage/StudentsPage.jsx'

const routes = [
  {
    index: true,
    path: '/',
    element: <MainPage />,
    title: 'Главная'
  },
  {
    path: '/statements',
    element: <StatementsPage />,
    title: 'Ведомости',
    onlyAuthorized: true,
    onlyTeachers: true
  },
  {
    path: '/groups',
    element: <GroupsPage />,
    title: 'Группы',
    onlyAuthorized: true,
    onlyTeachers: true
  },
  {
    path: '/students',
    element: <StudentsPage />,
    title: 'Студенты',
    onlyAuthorized: true,
    onlyTeachers: true
  },
  {
    path: '/subjects',
    element: <SubjectsPage />,
    title: 'Предметы',
    onlyAuthorized: true,
    onlyTeachers: true
  },
  {
    path: '/auth',
    element: <AuthPage />,
    title: 'Вход',
    onlyNoAuthorized: true
  },
  {
    path: '/register',
    element: <RegisterPage />,
    title: 'Регистрация',
    onlyNoAuthorized: true
  }
];

const router = createBrowserRouter([
  {
    path: '/',
    element: <App routes={routes} />,
    children: routes,
    errorElement: <ErrorPage />,
  },
]);

ReactDOM.createRoot(document.getElementById('root')).render(
  <React.StrictMode>
    <Toaster />
    <RouterProvider router={router} />
  </React.StrictMode>
)
