import { useState, useEffect } from "react";
import { useContext } from "react";
import { useNavigate } from "react-router-dom";
import { CurrentUserContext } from "../../contexts/CurrentUserContext";
import { getUserByUsernameAndPassword } from "../../utils/UserUtils";

const AuthPage = () => {
    const { currentUser, setCurrentUser } = useContext(
        CurrentUserContext
    );

    const navigate = useNavigate();

    useEffect(() => {
        if (currentUser) {
            navigate('/');
        }
    });


    const [inputFields, setInputFields] = useState({
        username: "",
        password: ""
    });

    const [errors, setErrors] = useState({});
    const [submitting, setSubmitting] = useState(false);

    const validateValues = (inputValues) => {
        let errors = {};
        if (inputValues.username.length <= 0) {
            errors.username = "Введите имя пользователя";
        }
        if (inputValues.password.length <= 0) {
            errors.password = "Введите пароль";
        }
        return errors;
    };

    const handleChange = (e) => {
        setInputFields({ ...inputFields, [e.target.name]: e.target.value });
    };

    const handleSubmit = async (event) => {
        event.preventDefault();
        let errors = validateValues(inputFields);
        setErrors(errors);
        if (errors.username == null && errors.password == null) {
            const user = await getUserByUsernameAndPassword(inputFields.username, inputFields.password);
            if (!user) {
                setErrors({
                    form: "Неверные логин или пароль"
                })
            }
            else {
                setCurrentUser(user);
            }
        }
        setSubmitting(true);
    };

    const finishSubmit = async () => {
        navigate('/');
    };

    useEffect(() => {
        if (Object.keys(errors).length === 0 && submitting && currentUser) {
            finishSubmit();
        }
    });

    return (
        <>
            <div className="d-flex flex-fill align-items-center justify-content-center">
                <form onSubmit={handleSubmit} className="d-flex flex-column justify-content-center">
                    <h5 className="text-center">Вход</h5>
                    <div className="mb-3">
                        {errors.form}
                    </div>
                    <div className="mb-3">
                        <input id="username" className="form-control" placeholder="Имя пользователя"
                            type="username"
                            name='username'
                            value={inputFields.username}
                            onChange={handleChange}>
                        </input>
                        {errors.username}
                    </div>
                    <div className="mb-3">
                        <input id="password" className="form-control" placeholder="Пароль"
                            type="password"
                            name='password'
                            value={inputFields.password}
                            onChange={handleChange}
                        >
                        </input>
                        {errors.password}
                    </div>
                    <button type="submit" className="btn btn-success" >Войти</button>
                </ form>
            </div>
        </>
    );
};

export default AuthPage;
