import StatementTableRow from "../../components/statementtablerow/statementtablerow";
import { useGroups } from "../../hooks/GroupHook";
import { useStatements } from "../../hooks/StatementsHook";
import { useSubjects } from "../../hooks/SubjectsHook";
import { useOnlyTeachers } from "../../hooks/UserHooks";
import { Container } from "react-bootstrap";
import useQueryParamFilter from "../../hooks/FilterHook";
import { useControlTypes } from "../../hooks/ControlTypesHook";
import StatementsApiService from "../../services/StatementsApiService";
import { useState } from "react";
import toast from "react-hot-toast";

const StatementsPage = () => {
    useOnlyTeachers();
    const [statementDate, setStatementDate] = useState('');
    const { subjects, handleSubjectsChange } = useSubjects();
    const { groups, handleGroupsChange } = useGroups();
    const { controlTypes, handleControlTypesChange } = useControlTypes();

    const { filterValue: subjectFilter, onFilterChange: onSubjectChange } = useQueryParamFilter("subjectId");
    const { filterValue: groupFilter, onFilterChange: onGroupChange } = useQueryParamFilter("groupId");
    const { filterValue: controlTypeFilter, onFilterChange: onControlTypeChange } = useQueryParamFilter("controltypeId");
    const { statements, handleStatementsChange } = useStatements({
        "subjectId": subjectFilter,
        "groupId": groupFilter,
        "controltypeId": controlTypeFilter
    });

    const onDateChange = () => {
        const date = document.getElementById('inputStatementDate').value;
        setStatementDate(date);
    };

    const onButtonAddStatementClick = async () => {
        if (subjectFilter && groupFilter && controlTypeFilter && statementDate) {
            await StatementsApiService.create(
                {
                    subjectId: subjectFilter,
                    groupId: groupFilter,
                    controltypeId: controlTypeFilter,
                    date: new Date(statementDate)
                }
            );
            toast.success('Ведомость создана');
            handleStatementsChange();
        }
    };

    const onButtonDeleteStatementClick = async (statementId) => {
        if (statementId) {
            await StatementsApiService.delete(statementId);
            toast.success("Ведомость успешно удалена");
            handleStatementsChange();
        }
    };


    return (
        <>
            <Container>
                <div className="d-flex flex-column flex-md-row">
                    <select name="subjectId" id="subjectId" className="me-none me-md-2 mb-2 mb-md-0" onChange={(e) => { onSubjectChange(e); handleStatementsChange(); }}>
                        <option value={null}>Выберите предмет</option>
                        {
                            subjects.map((subject, index) => <option key={index} value={subject.id}>{subject.name}</option>)
                        }
                    </select>
                    <select name="groupId" id="groupId" className="me-none me-md-2 mb-2 mb-md-0" onChange={(e) => { onGroupChange(e); handleStatementsChange(); }}>
                        <option value={null}>Выберите группу</option>
                        {
                            groups.map((group, index) => <option key={index} value={group.id}>{group.name}</option>)
                        }
                    </select>
                    <select name="controltypeId" id="controltypeId" className="mb-2 mb-md-0 me-none me-md-2" onChange={(e) => { onControlTypeChange(e); handleStatementsChange(); }}>
                        <option value={null}>Выберите тип</option>
                        {
                            controlTypes.map((ct, index) => <option key={index} value={ct.id}>{ct.name}</option>)
                        }
                    </select>
                    <input id="inputStatementDate" type="date" className="mb-2 mb-md-0 me-none me-md-2" value={statementDate} onChange={(e) => { onDateChange(e); handleStatementsChange(); }} />
                    <button className="btn btn-success btn-sm" onClick={onButtonAddStatementClick}>
                        Добавить ведомость
                    </button>
                </div>
                <table className="table">
                    <thead>
                        <tr>
                            <th scope="col">ID</th>
                            <th scope="col">Предмет</th>
                            <th scope="col">Группа</th>
                            <th scope="col">Тип</th>
                            <th scope="col">Дата</th>
                        </tr>
                    </thead>
                    <tbody>
                        {
                            statements.map((statement, index) => <StatementTableRow key={index} statement={statement} onDelete={onButtonDeleteStatementClick} />)
                        }
                    </tbody>
                </table>
            </Container>
        </>
    );
};

export default StatementsPage
